@@ -1,12 +1,11 @@
-from __future__ import annotations
+"""CLI tool for DDGS."""
 
 import csv
+import json
 import logging
-import os
 from concurrent.futures import ThreadPoolExecutor, as_completed
-from datetime import datetime
+from datetime import datetime, timezone
 from pathlib import Path
-from typing import Any
 from urllib.parse import unquote
 
 import click
@@ -14,7 +13,7 @@ import primp
 
 from . import __version__
 from .ddgs import DDGS
-from .utils import _expand_proxy_tb_alias, json_dumps
+from .utils import _expand_proxy_tb_alias
 
 logger = logging.getLogger(__name__)
 
@@ -38,7 +37,7 @@ COLORS = {
 }
 
 
-def _convert_tuple_to_csv(ctx: click.Context, param: click.Parameter, value: Any) -> str:
+def _convert_tuple_to_csv(_ctx: click.Context, _param: click.Parameter, value: tuple[str] | None) -> str:
     if value is not None and isinstance(value, tuple):
         return ",".join(value)
     return ""
@@ -46,7 +45,7 @@ def _convert_tuple_to_csv(ctx: click.Context, param: click.Parameter, value: Any
 
 def _save_data(query: str, data: list[dict[str, str]], function_name: str, filename: str | None) -> None:
     filename, ext = filename.rsplit(".", 1) if filename and filename.endswith((".csv", ".json")) else (None, filename)
-    filename = filename if filename else f"{function_name}_{query}_{datetime.now():%Y%m%d_%H%M%S}"
+    filename = filename if filename else f"{function_name}_{query}_{datetime.now(tz=timezone.utc):%Y%m%d_%H%M%S}"
     if ext == "csv":
         _save_csv(f"{filename}.{ext}", data)
     elif ext == "json":
@@ -54,12 +53,12 @@ def _save_data(query: str, data: list[dict[str, str]], function_name: str, filen
 
 
 def _save_json(jsonfile: str | Path, data: list[dict[str, str]]) -> None:
-    with open(jsonfile, "w", encoding="utf-8") as file:
-        file.write(json_dumps(data))
+    with Path(jsonfile).open("w", encoding="utf-8") as file:
+        file.write(json.dumps(data, ensure_ascii=False, indent=2))
 
 
 def _save_csv(csvfile: str | Path, data: list[dict[str, str]]) -> None:
-    with open(csvfile, "w", newline="", encoding="utf-8") as file:
+    with Path(csvfile).open("w", newline="", encoding="utf-8") as file:
         if data:
             headers = data[0].keys()
             writer = csv.DictWriter(file, fieldnames=headers, quoting=csv.QUOTE_MINIMAL)
@@ -74,18 +73,23 @@ def _print_data(data: list[dict[str, str]]) -> None:
             for j, (k, v) in enumerate(e.items(), start=1):
                 if v:
                     width = 300 if k in ("content", "href", "image", "source", "thumbnail", "url") else 78
-                    k = "language" if k == "detected_language" else k
+                    title = "language" if k == "detected_language" else k
                     text = click.wrap_text(
-                        f"{v}", width=width, initial_indent="", subsequent_indent=" " * 12, preserve_paragraphs=True
+                        f"{v}",
+                        width=width,
+                        initial_indent="",
+                        subsequent_indent=" " * 12,
+                        preserve_paragraphs=True,
                     )
                 else:
+                    title = k
                     text = v
-                click.secho(f"{k:<12}{text}", bg="black", fg=COLORS[j], overline=True)
+                click.secho(f"{title:<12}{text}", bg="black", fg=COLORS[j], overline=True)
             input()
 
 
 def _sanitize_query(query: str) -> str:
-    query = (
+    return (
         query.replace("filetype", "")
         .replace(":", "")
         .replace('"', "'")
@@ -95,19 +99,19 @@ def _sanitize_query(query: str) -> str:
         .replace("\\", "_")
         .replace(" ", "")
     )
-    return query
 
 
-def _download_file(url: str, dir_path: str, filename: str, proxy: str | None, verify: bool) -> None:
+def _download_file(url: str, dir_path: str, filename: str, proxy: str | None, *, verify: bool) -> None:
     try:
         resp = primp.Client(proxy=proxy, impersonate="random", impersonate_os="random", timeout=10, verify=verify).get(
-            url
+            url,
         )
         if resp.status_code == 200:
-            with open(os.path.join(dir_path, filename[:200]), "wb") as file:
+            f = Path(dir_path) / filename[:200]
+            with f.open("wb") as file:
                 file.write(resp.content)
-    except Exception as ex:
-        logger.debug(f"download_file url={url} {type(ex).__name__} {ex}")
+    except Exception as ex:  # noqa: BLE001
+        logger.debug("Error download_file url=%s: %r", url, ex)
 
 
 def _download_results(
@@ -116,11 +120,12 @@ def _download_results(
     function_name: str,
     proxy: str | None = None,
     threads: int | None = None,
-    verify: bool = True,
     pathname: str | None = None,
+    *,
+    verify: bool = True,
 ) -> None:
-    path = pathname if pathname else f"{function_name}_{query}_{datetime.now():%Y%m%d_%H%M%S}"
-    os.makedirs(path, exist_ok=True)
+    path = pathname if pathname else f"{function_name}_{query}_{datetime.now(tz=timezone.utc):%Y%m%d_%H%M%S}"
+    Path(path).mkdir(parents=True, exist_ok=True)
 
     threads = 10 if threads is None else threads
     with ThreadPoolExecutor(max_workers=threads) as executor:
@@ -128,11 +133,15 @@ def _download_results(
         for i, res in enumerate(results, start=1):
             url = res["image"] if function_name == "images" else res["href"]
             filename = unquote(url.split("/")[-1].split("?")[0])
-            f = executor.submit(_download_file, url, path, f"{i}_{filename}", proxy, verify)
+            f = executor.submit(_download_file, url, path, f"{i}_{filename}", proxy, verify=verify)
             futures.append(f)
 
-        with click.progressbar(  # type: ignore
-            length=len(futures), label="Downloading", show_percent=True, show_pos=True, width=50
+        with click.progressbar(
+            length=len(futures),
+            label="Downloading",
+            show_percent=True,
+            show_pos=True,
+            width=50,
         ) as bar:
             for future in as_completed(futures):
                 future.result()
@@ -141,20 +150,22 @@ def _download_results(
 
 @click.group(chain=True)
 def cli() -> None:
-    """DDGS CLI tool"""
-    pass
+    """DDGS CLI tool."""
 
 
 def safe_entry_point() -> None:
+    """Run the CLI tool in try-except block to catch all exceptions."""
+    logging.basicConfig(level=logging.WARNING)
     try:
         cli()
-    except Exception as ex:
-        click.echo(f"{type(ex).__name__}: {ex}")
+    except Exception as ex:  # noqa: BLE001
+        click.echo(f"{type(ex).__name__}: {ex!r}")
 
 
 @cli.command()
 def version() -> str:
-    print(__version__)
+    """Print and return version."""
+    print(__version__)  # noqa: T201
     return __version__
 
 
@@ -179,12 +190,10 @@ def version() -> str:
             "duckduckgo",
             "google",
             "mojeek",
-            "mullvad_brave",
-            "mullvad_google",
             "yandex",
             "yahoo",
             "wikipedia",
-        ]
+        ],
     ),
     multiple=True,
     callback=_convert_tuple_to_csv,
@@ -205,16 +214,17 @@ def text(
     page: int,
     backend: str,
     output: str | None,
-    download: bool,
     download_directory: str | None,
     threads: int,
     proxy: str | None,
+    *,
+    download: bool,
     verify: bool,
 ) -> None:
     """CLI function to perform a DDGS text metasearch."""
-    assert (query := keywords or query), "Please provide a query."
     data = DDGS(proxy=_expand_proxy_tb_alias(proxy), verify=verify).text(
         query=query,
+        keywords=keywords,  # deprecated
         region=region,
         safesearch=safesearch,
         timelimit=timelimit,
@@ -275,7 +285,7 @@ def text(
             "Gray",
             "Teal",
             "White",
-        ]
+        ],
     ),
 )
 @click.option("-type", "--type_image", type=click.Choice(["photo", "clipart", "gif", "transparent", "line"]))
@@ -305,17 +315,18 @@ def images(
     type_image: str | None,
     layout: str | None,
     license_image: str | None,
-    download: bool,
     download_directory: str | None,
     threads: int,
     output: str | None,
     proxy: str | None,
+    *,
+    download: bool,
     verify: bool,
 ) -> None:
     """CLI function to perform a DDGS images metasearch."""
-    assert (query := keywords or query), "Please provide a query."
     data = DDGS(proxy=_expand_proxy_tb_alias(proxy), verify=verify).images(
         query=query,
+        keywords=keywords,  # deprecated
         region=region,
         safesearch=safesearch,
         timelimit=timelimit,
@@ -381,12 +392,13 @@ def videos(
     license_videos: str | None,
     output: str | None,
     proxy: str | None,
+    *,
     verify: bool,
 ) -> None:
     """CLI function to perform a DDGS videos metasearch."""
-    assert (query := keywords or query), "Please provide a query."
     data = DDGS(proxy=_expand_proxy_tb_alias(proxy), verify=verify).videos(
         query=query,
+        keywords=keywords,  # deprecated
         region=region,
         safesearch=safesearch,
         timelimit=timelimit,
@@ -416,7 +428,7 @@ def videos(
     "-b",
     "--backend",
     default=["auto"],
-    type=click.Choice(["auto", "all", "duckduckgo", "yahoo"]),
+    type=click.Choice(["auto", "all", "bing", "duckduckgo", "yahoo"]),
     multiple=True,
     callback=_convert_tuple_to_csv,
 )
@@ -434,12 +446,13 @@ def news(
     backend: str,
     output: str | None,
     proxy: str | None,
+    *,
     verify: bool,
 ) -> None:
     """CLI function to perform a DDGS news metasearch."""
-    assert (query := keywords or query), "Please provide a query."
     data = DDGS(proxy=_expand_proxy_tb_alias(proxy), verify=verify).news(
         query=query,
+        keywords=keywords,  # deprecated
         region=region,
         safesearch=safesearch,
         timelimit=timelimit,
@@ -478,12 +491,13 @@ def books(
     backend: str,
     output: str | None,
     proxy: str | None,
+    *,
     verify: bool,
 ) -> None:
     """CLI function to perform a DDGS books metasearch."""
-    assert (query := keywords or query), "Please provide a query."
     data = DDGS(proxy=_expand_proxy_tb_alias(proxy), verify=verify).books(
         query=query,
+        keywords=keywords,  # deprecated
         max_results=max_results,
         page=page,
         backend=backend,
@@ -495,4 +509,4 @@ def books(
 
 
 if __name__ == "__main__":
-    cli(prog_name="ddgs")
+    safe_entry_point()
