@@ -1,13 +1,14 @@
-from __future__ import annotations
+"""Brave search engine implementation."""
 
-from typing import Any
+from collections.abc import Mapping
+from typing import Any, ClassVar
 
-from ..base import BaseSearchEngine
-from ..results import TextResult
+from ddgs.base import BaseSearchEngine
+from ddgs.results import TextResult
 
 
 class Brave(BaseSearchEngine[TextResult]):
-    """Brave search engine"""
+    """Brave search engine."""
 
     name = "brave"
     category = "text"
@@ -17,17 +18,24 @@ class Brave(BaseSearchEngine[TextResult]):
     search_method = "GET"
 
     items_xpath = "//div[@data-type='web']"
-    elements_xpath = {
+    elements_xpath: ClassVar[Mapping[str, str]] = {
         "title": ".//div[(contains(@class,'title') or contains(@class,'sitename-container')) and position()=last()]//text()",  # noqa: E501
-        "href": "./a/@href",
-        "body": ".//div[contains(@class, 'description')]//text()",
+        "href": ".//a[div[contains(@class, 'title')]]/@href",
+        "body": ".//div[contains(@class, 'snippet')]//div[contains(@class, 'content')]//text()",
     }
 
     def build_payload(
-        self, query: str, region: str, safesearch: str, timelimit: str | None, page: int = 1, **kwargs: Any
+        self,
+        query: str,
+        region: str,
+        safesearch: str,
+        timelimit: str | None,
+        page: int = 1,
+        **kwargs: str,  # noqa: ARG002
     ) -> dict[str, Any]:
+        """Build a payload for the search request."""
         payload = {"q": query, "source": "web"}
-        country, lang = region.lower().split("-")
+        country, _lang = region.lower().split("-")
         cookies = {country: country, "useLocation": "0"}
         if safesearch != "moderate":
             cookies["safesearch"] = "strict" if safesearch == "on" else "off"
